<?php
/**
 * This file outputs the PRIMA-specific inpost option boxes.
 * It also handles saving the user input from those boxes, when a
 * post or page gets published or updated.
 *
 */

/**
 * This code adds a new box to the post/page edit screen,
 * so that the user can set layout options on a per-post/page basis.
 *
 * prima_add_post_layout_box() is used to register the boxes.
 * @uses add_meta_box
 * prima_post_layout_box() generates the content in the boxes.
 * @uses wp_create_nonce, checked, prima_get_custom_field
 *
 * @since 0.2.2
 */
// add_action('admin_menu', 'prima_add_post_layout_box');
function prima_add_post_layout_box() {
	
	if ( !current_theme_supports('prima-inpost-layouts') )
		return;
	
	foreach ( (array)get_post_types( array( 'public' => true ) ) as $type ) {
		if ( post_type_supports( $type, 'prima-layouts' ) || $type == 'post' || $type = 'page' ) {
			add_meta_box('prima_post_layout_box', __('Prima Layout Options', PRIMA_DOMAIN), 'prima_post_layout_box', $type, 'normal', 'high');
		}	
	}

}
function prima_post_layout_box() { ?>

	<?php wp_nonce_field( plugin_basename(__FILE__), 'prima_post_layout_nonce' ); ?>
	
	<?php $layout = prima_get_custom_field('_prima_layout'); ?>
	
	<input type="radio" name="_prima_layout" id="default-layout" value="" <?php checked('', $layout); ?> /> <label class="default" for="default-layout"><?php printf( __('Default Layout set in <a href="%s">Theme Settings</a>', PRIMA_DOMAIN), admin_url('admin.php?page=prima') ); ?></label>
	
	<br style="clear: both;" /><br />
	
	<?php
	foreach ( prima_get_layouts() as $id => $data ) {
		
		printf( '<label class="box"><input type="radio" name="_prima_layout" id="%s" value="%s" %s /> <img src="%s" alt="%s" /></label>', esc_attr( $id ), esc_attr( $id ), checked($id, $layout, false), esc_url( $data['img'] ), esc_attr( $data['label'] ) );
		
	}
	?>
	
	<br style="clear: both;" />
	
	<p><label for="prima_custom_body_class"><b><?php _e('Custom Body Class', PRIMA_DOMAIN); ?></b></label></p>
	<p><input style="width: 99%;" type="text" name="_prima_custom_body_class" id="prima_custom_body_class" value="<?php echo esc_attr( sanitize_html_class( prima_get_custom_field('_prima_custom_body_class') ) ); ?>" /></p>
	
	<p><label for="prima_custom_post_class"><b><?php _e('Custom Post Class', PRIMA_DOMAIN); ?></b></label></p>
	<p><input style="width: 99%;" type="text" name="_prima_custom_post_class" id="prima_custom_post_class" value="<?php echo esc_attr( sanitize_html_class( prima_get_custom_field('_prima_custom_post_class') ) ); ?>" /></p>
	
<?php
}

/**
 * This function saves the layout options when we save a post/page.
 * It does so by grabbing the array passed in $_POST, looping through
 * it, and saving each key/value pair as a custom field.
 *
 * @uses wp_verify_nonce, plugin_basename, current_user_can
 * @uses add_post_meta, delete_post_meta, get_custom_field
 *
 * @since 0.2.2
 */
// add_action('save_post', 'prima_post_layout_save', 1, 2);
function prima_post_layout_save($post_id, $post) {
	
	//	verify the nonce
	if ( !isset($_POST['prima_post_layout_nonce']) || !wp_verify_nonce( $_POST['prima_post_layout_nonce'], plugin_basename(__FILE__) ) )
		return $post_id;
		
	//	don't try to save the data under autosave, ajax, or future post.
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return;
	if ( defined('DOING_AJAX') && DOING_AJAX ) return;
	if ( defined('DOING_CRON') && DOING_CRON ) return;

	//	is the user allowed to edit the post or page?
	if ( ('page' == $_POST['post_type'] && !current_user_can('edit_page', $post_id)) || !current_user_can('edit_post', $post_id ) )
		return $post_id;
		
	/**
	 * Save all the layout/class data
	 *
	 */
	$prima_layout = $_POST['_prima_layout'];
	
	if ( $prima_layout ) {
		//	save/update
		update_post_meta($post_id, '_prima_layout', $prima_layout);
	} else {
		//	delete if blank
		delete_post_meta($post_id, '_prima_layout');
	}
	
	$prima_custom_body_class = $_POST['_prima_custom_body_class'];
	
	if ( $prima_custom_body_class ) {
		//	save/update
		update_post_meta($post_id, '_prima_custom_body_class', $prima_custom_body_class);
	} else {
		//	delete if blank
		delete_post_meta($post_id, '_prima_custom_body_class');
	}
	
	$prima_custom_post_class = $_POST['_prima_custom_post_class'];
	
	if ( $prima_custom_post_class ) {
		//	save/update
		update_post_meta($post_id, '_prima_custom_post_class', $prima_custom_post_class);
	} else {
		//	delete if blank
		delete_post_meta($post_id, '_prima_custom_post_class');
	}
	
}